@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::DROLSKY;
-# git description: v0.16-2-g3414fa5
-$Dist::Zilla::PluginBundle::DROLSKY::VERSION = '0.17';
+# git description: v0.17-3-g7e79a28
+$Dist::Zilla::PluginBundle::DROLSKY::VERSION = '0.18';
 
 use v5.10;
 
@@ -17,12 +17,12 @@ use Pod::Weaver::Section::Contributors;
 use Dist::Zilla::Plugin::Authority;
 use Dist::Zilla::Plugin::AutoPrereqs;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
-use Dist::Zilla::Plugin::ContributorsFromGit;
 use Dist::Zilla::Plugin::CopyReadmeFromBuild;
 use Dist::Zilla::Plugin::EOLTests;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
 use Dist::Zilla::Plugin::Git::Commit;
+use Dist::Zilla::Plugin::Git::Contributors;
 use Dist::Zilla::Plugin::Git::Describe;
 use Dist::Zilla::Plugin::Git::Push;
 use Dist::Zilla::Plugin::Git::Tag;
@@ -267,11 +267,11 @@ sub _build_plugins {
             ),
         qw(
             CheckPrereqsIndexed
-            ContributorsFromGit
             CopyReadmeFromBuild
             Git::CheckFor::CorrectBranch
             Git::CheckFor::MergeConflicts
             Git::Describe
+            Git::Contributors
             InstallGuide
             Meta::Contributors
             MetaConfig
@@ -379,15 +379,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =for Pod::Coverage .*
 
